/****************************************************************************
** Meta object code from reading C++ file 'scan.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../filelight-26.07.90/src/scan.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'scan.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9Filelight11ScanManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto Filelight::ScanManager::qt_create_metaobjectdata<qt_meta_tag_ZN9Filelight11ScanManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Filelight::ScanManager",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "completed",
        "",
        "std::shared_ptr<Folder>",
        "folder",
        "aboutToEmptyCache",
        "branchCacheHit",
        "tree",
        "runningChanged",
        "aborted",
        "abort",
        "emptyCache",
        "cacheTree",
        "foundCached",
        "files",
        "totalSize",
        "size_t",
        "running"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'completed'
        QtMocHelpers::SignalData<void(std::shared_ptr<Folder>)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'aboutToEmptyCache'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'branchCacheHit'
        QtMocHelpers::SignalData<void(std::shared_ptr<Folder>)>(10, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 11 },
        }}),
        // Signal 'runningChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'aborted'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'abort'
        QtMocHelpers::SlotData<bool()>(14, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'emptyCache'
        QtMocHelpers::SlotData<void()>(15, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'cacheTree'
        QtMocHelpers::SlotData<void(std::shared_ptr<Folder>)>(16, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'foundCached'
        QtMocHelpers::SlotData<void(std::shared_ptr<Folder>)>(17, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Method 'files'
        QtMocHelpers::MethodData<int() const>(18, 6, QMC::AccessPublic, QMetaType::Int),
        // Method 'totalSize'
        QtMocHelpers::MethodData<size_t() const>(19, 6, QMC::AccessPublic, 0x80000000 | 20),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'running'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags, 3),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<ScanManager, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Filelight::ScanManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Filelight11ScanManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Filelight11ScanManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9Filelight11ScanManagerE_t>.metaTypes,
    nullptr
} };

void Filelight::ScanManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ScanManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->completed((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<Folder>>>(_a[1]))); break;
        case 1: _t->aboutToEmptyCache(); break;
        case 2: _t->branchCacheHit((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<Folder>>>(_a[1]))); break;
        case 3: _t->runningChanged(); break;
        case 4: _t->aborted(); break;
        case 5: { bool _r = _t->abort();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 6: _t->emptyCache(); break;
        case 7: _t->cacheTree((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<Folder>>>(_a[1]))); break;
        case 8: _t->foundCached((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<Folder>>>(_a[1]))); break;
        case 9: { int _r = _t->files();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 10: { size_t _r = _t->totalSize();
            if (_a[0]) *reinterpret_cast<size_t*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ScanManager::*)(std::shared_ptr<Folder> )>(_a, &ScanManager::completed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ScanManager::*)()>(_a, &ScanManager::aboutToEmptyCache, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ScanManager::*)(std::shared_ptr<Folder> )>(_a, &ScanManager::branchCacheHit, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ScanManager::*)()>(_a, &ScanManager::runningChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ScanManager::*)()>(_a, &ScanManager::aborted, 4))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->running(); break;
        default: break;
        }
    }
}

const QMetaObject *Filelight::ScanManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Filelight::ScanManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Filelight11ScanManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Filelight::ScanManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void Filelight::ScanManager::completed(std::shared_ptr<Folder> _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Filelight::ScanManager::aboutToEmptyCache()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Filelight::ScanManager::branchCacheHit(std::shared_ptr<Folder> _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Filelight::ScanManager::runningChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Filelight::ScanManager::aborted()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
