/****************************************************************************
** Meta object code from reading C++ file 'radialMap.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../filelight-26.07.90/src/radialMap/radialMap.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'radialMap.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9RadialMap7SegmentE_t {};
} // unnamed namespace

template <> constexpr inline auto RadialMap::Segment::qt_create_metaobjectdata<qt_meta_tag_ZN9RadialMap7SegmentE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "RadialMap::Segment",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "only created by Map",
        "highlightChanged",
        "",
        "paletteChanged",
        "start",
        "length",
        "end",
        "url",
        "QUrl",
        "isFolder",
        "displayName",
        "displayPath",
        "pen",
        "brush",
        "color",
        "humanReadableSize",
        "files",
        "fake",
        "QColor",
        "uuid",
        "isFilesGroup"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'highlightChanged'
        QtMocHelpers::SignalData<void()>(7, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'paletteChanged'
        QtMocHelpers::SignalData<void()>(9, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'start'
        QtMocHelpers::MethodData<uint() const>(10, 8, QMC::AccessPublic, QMetaType::UInt),
        // Method 'length'
        QtMocHelpers::MethodData<uint() const>(11, 8, QMC::AccessPublic, QMetaType::UInt),
        // Method 'end'
        QtMocHelpers::MethodData<uint() const>(12, 8, QMC::AccessPublic, QMetaType::UInt),
        // Method 'url'
        QtMocHelpers::MethodData<QUrl() const>(13, 8, QMC::AccessPublic, 0x80000000 | 14),
        // Method 'isFolder'
        QtMocHelpers::MethodData<bool() const>(15, 8, QMC::AccessPublic, QMetaType::Bool),
        // Method 'displayName'
        QtMocHelpers::MethodData<QString() const>(16, 8, QMC::AccessPublic, QMetaType::QString),
        // Method 'displayPath'
        QtMocHelpers::MethodData<QString() const>(17, 8, QMC::AccessPublic, QMetaType::QString),
        // Method 'pen'
        QtMocHelpers::MethodData<void() const>(18, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'brush'
        QtMocHelpers::MethodData<void() const>(19, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'color'
        QtMocHelpers::MethodData<QString()>(20, 8, QMC::AccessPublic, QMetaType::QString),
        // Method 'humanReadableSize'
        QtMocHelpers::MethodData<QString() const>(21, 8, QMC::AccessPublic, QMetaType::QString),
        // Method 'files'
        QtMocHelpers::MethodData<uint() const>(22, 8, QMC::AccessPublic, QMetaType::UInt),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'fake'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'color'
        QtMocHelpers::PropertyData<QColor>(20, 0x80000000 | 24, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'brush'
        QtMocHelpers::PropertyData<QColor>(19, 0x80000000 | 24, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'pen'
        QtMocHelpers::PropertyData<QColor>(18, 0x80000000 | 24, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'uuid'
        QtMocHelpers::PropertyData<QString>(25, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'isFilesGroup'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<Segment, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject RadialMap::Segment::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9RadialMap7SegmentE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9RadialMap7SegmentE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9RadialMap7SegmentE_t>.metaTypes,
    nullptr
} };

void RadialMap::Segment::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Segment *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->highlightChanged(); break;
        case 1: _t->paletteChanged(); break;
        case 2: { uint _r = _t->start();
            if (_a[0]) *reinterpret_cast<uint*>(_a[0]) = std::move(_r); }  break;
        case 3: { uint _r = _t->length();
            if (_a[0]) *reinterpret_cast<uint*>(_a[0]) = std::move(_r); }  break;
        case 4: { uint _r = _t->end();
            if (_a[0]) *reinterpret_cast<uint*>(_a[0]) = std::move(_r); }  break;
        case 5: { QUrl _r = _t->url();
            if (_a[0]) *reinterpret_cast<QUrl*>(_a[0]) = std::move(_r); }  break;
        case 6: { bool _r = _t->isFolder();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 7: { QString _r = _t->displayName();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 8: { QString _r = _t->displayPath();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 9: _t->pen(); break;
        case 10: _t->brush(); break;
        case 11: { QString _r = _t->color();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 12: { QString _r = _t->humanReadableSize();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 13: { uint _r = _t->files();
            if (_a[0]) *reinterpret_cast<uint*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Segment::*)()>(_a, &Segment::highlightChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Segment::*)()>(_a, &Segment::paletteChanged, 1))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->m_fake; break;
        case 1: *reinterpret_cast<QColor*>(_v) = _t->color(); break;
        case 2: *reinterpret_cast<QColor*>(_v) = _t->brush(); break;
        case 3: *reinterpret_cast<QColor*>(_v) = _t->pen(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->m_uuid; break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->isFilesGroup(); break;
        default: break;
        }
    }
}

const QMetaObject *RadialMap::Segment::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *RadialMap::Segment::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9RadialMap7SegmentE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int RadialMap::Segment::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 14;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void RadialMap::Segment::highlightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void RadialMap::Segment::paletteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
