/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<Config.h>)
#  include <Config.h>
#endif
#if __has_include(<contextMenuContext.h>)
#  include <contextMenuContext.h>
#endif
#if __has_include(<dropperItem.h>)
#  include <dropperItem.h>
#endif
#if __has_include(<fileModel.h>)
#  include <fileModel.h>
#endif
#if __has_include(<mainContext.h>)
#  include <mainContext.h>
#endif
#if __has_include(<map.h>)
#  include <map.h>
#endif
#if __has_include(<radialMap.h>)
#  include <radialMap.h>
#endif
#if __has_include(<scan.h>)
#  include <scan.h>
#endif
#if __has_include(<windowThemer.h>)
#  include <windowThemer.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_filelight()
{
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<Config>("org.kde.filelight", 1);
    {
        Q_CONSTINIT static auto metaType = QQmlPrivate::metaTypeForNamespace(
            [](const QtPrivate::QMetaTypeInterface *) {return &Filelight::staticMetaObject;},
            "Filelight");
        QMetaType(&metaType).id();
    }
    qmlRegisterNamespaceAndRevisions(&Filelight::staticMetaObject, "org.kde.filelight", 1, nullptr, &Filelight::staticMetaObject, nullptr);
    qmlRegisterEnum<Filelight::Dirty>("Filelight::Dirty");
    qmlRegisterEnum<Filelight::MapScheme>("Filelight::MapScheme");
    qmlRegisterTypesAndRevisions<Filelight::ContextMenuContext>("org.kde.filelight", 1);
    qmlRegisterTypesAndRevisions<Filelight::DropperItem>("org.kde.filelight", 1);
    qmlRegisterAnonymousType<QQuickItem, 254>("org.kde.filelight", 1);
    qmlRegisterTypesAndRevisions<Filelight::FileModel>("org.kde.filelight", 1);
    qmlRegisterEnum<Filelight::FileModel::Role>("Filelight::FileModel::Role");
    qmlRegisterTypesAndRevisions<Filelight::MainContext>("org.kde.filelight", 1);
    qmlRegisterTypesAndRevisions<Filelight::ScanManager>("org.kde.filelight", 1);
    QMetaType::fromType<QAbstractItemModel *>().id();
    qmlRegisterEnum<QAbstractItemModel::LayoutChangeHint>("QAbstractItemModel::LayoutChangeHint");
    qmlRegisterEnum<QAbstractItemModel::CheckIndexOption>("QAbstractItemModel::CheckIndexOption");
    QMetaType::fromType<QAbstractListModel *>().id();
    qmlRegisterTypesAndRevisions<RadialMap::Map>("org.kde.filelight", 1);
    qmlRegisterTypesAndRevisions<RadialMap::Segment>("org.kde.filelight", 1);
    qmlRegisterTypesAndRevisions<WindowThemer>("org.kde.filelight", 1);
    QT_WARNING_POP
    qmlRegisterModule("org.kde.filelight", 1, 0);
}

static const QQmlModuleRegistration orgkdefilelightRegistration("org.kde.filelight", qml_register_types_org_kde_filelight);
