/****************************************************************************
** Meta object code from reading C++ file 'map.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../filelight-26.07.90/src/radialMap/map.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'map.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9RadialMap3MapE_t {};
} // unnamed namespace

template <> constexpr inline auto RadialMap::Map::qt_create_metaobjectdata<qt_meta_tag_ZN9RadialMap3MapE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "RadialMap::Map",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "RadialMap",
        "rectChanged",
        "",
        "signatureChanged",
        "zoomIn",
        "zoomOut",
        "refresh",
        "Filelight::Dirty",
        "filth",
        "createFromCacheObject",
        "RadialMap::Segment*",
        "segment",
        "invalidate",
        "signature",
        "QList<QVariant>",
        "displayPath",
        "valid",
        "rect",
        "QRectF",
        "overallSize",
        "numberOfChildren",
        "rootUrl",
        "QUrl",
        "rootSegment"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'rectChanged'
        QtMocHelpers::SignalData<void()>(6, 7, QMC::AccessPublic, QMetaType::Void),
        // Signal 'signatureChanged'
        QtMocHelpers::SignalData<void()>(8, 7, QMC::AccessPublic, QMetaType::Void),
        // Slot 'zoomIn'
        QtMocHelpers::SlotData<void()>(9, 7, QMC::AccessPublic, QMetaType::Void),
        // Slot 'zoomOut'
        QtMocHelpers::SlotData<void()>(10, 7, QMC::AccessPublic, QMetaType::Void),
        // Slot 'refresh'
        QtMocHelpers::SlotData<void(Filelight::Dirty)>(11, 7, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'createFromCacheObject'
        QtMocHelpers::SlotData<void(RadialMap::Segment *)>(14, 7, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Method 'invalidate'
        QtMocHelpers::MethodData<void()>(17, 7, QMC::AccessPublic, QMetaType::Void),
        // Method 'signature'
        QtMocHelpers::MethodData<QList<QVariant>()>(18, 7, QMC::AccessPublic, 0x80000000 | 19),
        // Method 'displayPath'
        QtMocHelpers::MethodData<QString() const>(20, 7, QMC::AccessPublic, QMetaType::QString),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'valid'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'rect'
        QtMocHelpers::PropertyData<QRectF>(22, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 0),
        // property 'signature'
        QtMocHelpers::PropertyData<QList<QVariant>>(18, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'overallSize'
        QtMocHelpers::PropertyData<QString>(24, QMetaType::QString, QMC::DefaultPropertyFlags, 1),
        // property 'numberOfChildren'
        QtMocHelpers::PropertyData<uint>(25, QMetaType::UInt, QMC::DefaultPropertyFlags, 1),
        // property 'rootUrl'
        QtMocHelpers::PropertyData<QUrl>(26, 0x80000000 | 27, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'rootSegment'
        QtMocHelpers::PropertyData<QObject*>(28, QMetaType::QObjectStar, QMC::DefaultPropertyFlags, 1),
        // property 'displayPath'
        QtMocHelpers::PropertyData<QString>(20, QMetaType::QString, QMC::DefaultPropertyFlags, 1),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    1,    5 },
    });
    return QtMocHelpers::metaObjectData<Map, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject RadialMap::Map::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9RadialMap3MapE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9RadialMap3MapE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9RadialMap3MapE_t>.metaTypes,
    nullptr
} };

void RadialMap::Map::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Map *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->rectChanged(); break;
        case 1: _t->signatureChanged(); break;
        case 2: _t->zoomIn(); break;
        case 3: _t->zoomOut(); break;
        case 4: _t->refresh((*reinterpret_cast<std::add_pointer_t<Filelight::Dirty>>(_a[1]))); break;
        case 5: _t->createFromCacheObject((*reinterpret_cast<std::add_pointer_t<RadialMap::Segment*>>(_a[1]))); break;
        case 6: _t->invalidate(); break;
        case 7: { QList<QVariant> _r = _t->signature();
            if (_a[0]) *reinterpret_cast<QList<QVariant>*>(_a[0]) = std::move(_r); }  break;
        case 8: { QString _r = _t->displayPath();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Filelight::Dirty >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< RadialMap::Segment* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Map::*)()>(_a, &Map::rectChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Map::*)()>(_a, &Map::signatureChanged, 1))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->isValid(); break;
        case 1: *reinterpret_cast<QRectF*>(_v) = _t->m_rect; break;
        case 2: *reinterpret_cast<QList<QVariant>*>(_v) = _t->signature(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->overallSize(); break;
        case 4: *reinterpret_cast<uint*>(_v) = _t->numberOfChildren(); break;
        case 5: *reinterpret_cast<QUrl*>(_v) = _t->rootUrl(); break;
        case 6: *reinterpret_cast<QObject**>(_v) = _t->rootSegment(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->displayPath(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1:
            if (QtMocHelpers::setProperty(_t->m_rect, *reinterpret_cast<QRectF*>(_v)))
                Q_EMIT _t->rectChanged();
            break;
        default: break;
        }
    }
}

const QMetaObject *RadialMap::Map::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *RadialMap::Map::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9RadialMap3MapE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int RadialMap::Map::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void RadialMap::Map::rectChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void RadialMap::Map::signatureChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
