// This file is generated by kconfig_compiler_kf6 from filelightsettings.kcfg.
// All changes you do to this file will be lost.
#ifndef FILELIGHTSETTINGS_H
#define FILELIGHTSETTINGS_H

#include <qglobal.h>
#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class FilelightSettings : public KConfigSkeleton
{
  public:

    FilelightSettings( );
    ~FilelightSettings() override;

    /**
      Set Scan across filesystem boundaries
    */
    void setScanAcrossMounts( bool v )
    {
      if (!isScanAcrossMountsImmutable())
        mScanAcrossMounts = v;
    }

    /**
      Get Scan across filesystem boundaries
    */
    bool scanAcrossMounts() const
    {
      return mScanAcrossMounts;
    }

    /**
      Is Scan across filesystem boundaries Immutable
    */
    bool isScanAcrossMountsImmutable() const
    {
      return isImmutable( QStringLiteral( "scanAcrossMounts" ) );
    }

    /**
      Set Scan remote filesystems
    */
    void setScanRemoteMounts( bool v )
    {
      if (!isScanRemoteMountsImmutable())
        mScanRemoteMounts = v;
    }

    /**
      Get Scan remote filesystems
    */
    bool scanRemoteMounts() const
    {
      return mScanRemoteMounts;
    }

    /**
      Is Scan remote filesystems Immutable
    */
    bool isScanRemoteMountsImmutable() const
    {
      return isImmutable( QStringLiteral( "scanRemoteMounts" ) );
    }

    /**
      Set Show small files
    */
    void setShowSmallFiles( bool v )
    {
      if (!isShowSmallFilesImmutable())
        mShowSmallFiles = v;
    }

    /**
      Get Show small files
    */
    bool showSmallFiles() const
    {
      return mShowSmallFiles;
    }

    /**
      Is Show small files Immutable
    */
    bool isShowSmallFilesImmutable() const
    {
      return isImmutable( QStringLiteral( "showSmallFiles" ) );
    }

    /**
      Set Show folders sidebar
    */
    void setShowFoldersSidebar( bool v )
    {
      if (!isShowFoldersSidebarImmutable())
        mShowFoldersSidebar = v;
    }

    /**
      Get Show folders sidebar
    */
    bool showFoldersSidebar() const
    {
      return mShowFoldersSidebar;
    }

    /**
      Is Show folders sidebar Immutable
    */
    bool isShowFoldersSidebarImmutable() const
    {
      return isImmutable( QStringLiteral( "showFoldersSidebar" ) );
    }

    /**
      Set Contrast
    */
    void setContrast( int v )
    {
      if (!isContrastImmutable())
        mContrast = v;
    }

    /**
      Get Contrast
    */
    int contrast() const
    {
      return mContrast;
    }

    /**
      Is Contrast Immutable
    */
    bool isContrastImmutable() const
    {
      return isImmutable( QStringLiteral( "contrast" ) );
    }

    /**
      Set Color Scheme
    */
    void setScheme( int v )
    {
      if (!isSchemeImmutable())
        mScheme = v;
    }

    /**
      Get Color Scheme
    */
    int scheme() const
    {
      return mScheme;
    }

    /**
      Is Color Scheme Immutable
    */
    bool isSchemeImmutable() const
    {
      return isImmutable( QStringLiteral( "scheme" ) );
    }

    /**
      Set Do not scan these folders
    */
    void setSkipList( const QStringList & v )
    {
      if (!isSkipListImmutable())
        mSkipList = v;
    }

    /**
      Get Do not scan these folders
    */
    QStringList skipList() const
    {
      return mSkipList;
    }

    /**
      Is Do not scan these folders Immutable
    */
    bool isSkipListImmutable() const
    {
      return isImmutable( QStringLiteral( "skipList" ) );
    }

  protected:

    // filelight_part
    bool mScanAcrossMounts;
    bool mScanRemoteMounts;
    bool mShowSmallFiles;
    bool mShowFoldersSidebar;
    int mContrast;
    int mScheme;
    QStringList mSkipList;
};

#endif

